#! /bin/sh

# boujou installation script.
#
# Copyright (C) OMG plc 2009 
# All rights reserved.  This software is protected by copyright 
# law and international treaties.  No part of this software / document 
# may be reproduced or distributed in any form or by any means, 
# whether transiently or incidentally to some other use of this software, 
# without the written permission of the copyright owner.

version_name="boujou-5.0.0"
default_dest="/usr/local/"
exe_name="boujou5.0"
demo_exe_name="boujou5.0_demo"
demo_version=0
support_email="boujousupport@vicon.com"

echo ""
echo "*** Installing " $version_name
echo "*** Copyright (C) OMG plc 2009"
echo ""


# Check to see if glibc version is compatible
echo "Testing glibc..."
compGLIBC=0
glibcVer=`/lib/libc.so.6 | head -1 | awk '{sub(",",""); print$7}'`
glibcMaj=`echo $glibcVer | cut -d. -f1`
glibcMin=`echo $glibcVer | cut -d. -f2`
if [ $glibcMaj -ge 2 ]; then
    if [ $glibcMin -ge 3 ]; then
        compGLIBC=1
        echo "...Passed"
    fi
fi
if [ $compGLIBC -eq 0 ]; then
    echo "Failed: WARNING boujou may not run correctly with version "$glibcVer""
    echo "of glibc."
fi

# Check if the kernel version is compatible
echo "Testing kernel..."
compKER=0
KERNELVERSION="$($echo uname -r | cut -d- -f1)"
KerVer=`echo $KERNELVERSION | awk '{print substr($1,1,3)}'`
KerMinVer=`echo $KERNELVERSION | cut -d. -f3`
if [ "$KerVer" = "2.6" ]; then
    if [ $KerMinVer -ge 9 ]; then
        compKER=1
    fi
fi
if [ $compKER -eq 1 ]; then
    echo "...Passed"
else
    echo "Failed: WARNING boujou may not be fully compatible with kernel"
    echo "version "$KERNELVERSION"."
fi

echo ""

# Check all compatibilities and if any failed warn user and ask if they would like to continue
if [ `expr $compKER + $compGLIBC` -ne 2 ]; then
    echo "WARNING: This installation has spotted some potential"
    echo "compatibility issues. If you have any questions about"
    echo "this please contact $support_email with the"
    echo "distribution, kernel and graphics card you are using."
    read -n 1 -p "Continue with installation (y/n) ? " resp
    if [ $resp != "y" -a $resp != "Y" ]; then
        exit 0;
    fi
else
echo "As far as we are aware your system is compatible with "$version_name"."
echo "Should you experience any problems please contact" $support_email
fi

echo ""
echo "N.B. The default graphics drivers available with some linux distributions"
echo "may be incompatible with certain graphics hardware. If problems occur then it is "
echo "highly advisable to install the latest graphics drivers from the graphics "
echo "card manufacturer." 

echo ""

# Does the user wish to install to a destination other than the default?
echo "Default installation path:" $default_dest
echo ""
read -p "Do you wish to specify a different install path (y/n) ? " resp
if [ $resp != "n" -a $resp != "N" ]; then
    default_dest=""
fi

# If default_dest == "" then the user needs to change install path, get it
if [ -z $default_dest ]; then
    valid_location=0
    while [ $valid_location -eq 0 ]; do
	read -p "Enter installation path : " default_dest
	if [ -z $default_dest ]; then
	    echo "You must specify a valid installation path."
            exit 0;
	else
	    valid_location=1;
	fi
    done
fi

# Check that the destination is valid
dest_directory=$default_dest
if [ ! -d $default_dest ]; then
   dest_directory=`dirname $default_dest`
fi

if [ ! -w $dest_directory ]; then
    echo "You do not have write access to " $dest_directory
    exit 0;
fi

# license check
cat license_agreement.txt | more
echo "---------------------------------------------------"
echo "Do you accept all the terms of the License agreement (y/n) ?"
echo "If you choose No (n), the setup will terminate."
echo "To install boujou, you must accept this agreement."
read rsp
while [ 1 -eq 1 ]
do
if [ "$rsp" = "n" -o "$rsp" = "y" ]; then
  break
fi
echo "Please enter (y/n)"
read rsp
done

if [ "$rsp" = "n" ]; then
     echo "Quitting..."
     exit 1
fi


# Initialize SentinelSafenet system
echo ""
echo "Initializing SentinelSafenet Licensing"
echo ""
# Check if the user is logged on with root permissions 
if [ $(id -u) != "0" ]; then
    echo "  You do not appear to have root privileges."
    echo "  In order to correctly setup boujou's licensing you must run boujou_lsinit with root privileges."
    echo ""
    echo "  After installation boujou_lsinit can be run from the directory :"
    echo "  " $default_dest/share/$version_name/bin 
    echo ""
    read -p "Continue with installation (y/n) ? " resp
    if [ $resp != "y" -a $resp != "Y" ]; then
        exit 0;
    fi
else
    ./bin/boujou_lsinit
fi


# create the bin and doc directories if necessary
if [ ! -d $default_dest/bin ]; then
  mkdir -p  $default_dest/bin
fi

if [ ! -d $default_dest/share/$version_name ]; then
  mkdir -p $default_dest/share/$version_name
fi

# Copy files and set permissions
echo "Copying files..."
cp -r ./bin $default_dest/share/$version_name/
cp -r ./doc $default_dest/share/$version_name/
cp ./readme.txt $default_dest/share/$version_name/doc/

mkdir -p $default_dest/share/$version_name/licensing
cp ./licensing/echoid $default_dest/share/$version_name/licensing/
cp ./licensing/echoid.dat $default_dest/share/$version_name/licensing/

cd $default_dest/bin
ln -s -f ../share/$version_name/bin/boujou $exe_name
chmod a+rwx $default_dest/bin/$exe_name

ln -s -f ../share/$version_name/bin/boujou_demo $demo_exe_name
chmod a+rwx $default_dest/bin/$demo_exe_name

echo ""
echo "Installation completed successfully."

